# frozen_string_literal: true

class ApplicationController

  def render(options = {})
    status = options[:status] || 200
    headers = (options[:headers] || {}).with_indifferent_access

    puts <<~HEREDOC
      ApplicationController#render
      status: #{status}
      headers: #{headers}
      options: #{options}
    HEREDOC

    if options[:json]
      return [ status, headers.merge({ 'Content-Type' => 'application/json' }), [ JSON.generate(options[:json]) ] ]
    elsif options[:html]
      return [ status, headers.merge({ 'Content-Type' => 'text/html' }), [ options[:html] ] ]
    elsif options[:custom]
      return [ status, headers, [ options[:custom][:body] ] ]
    else
      # raise 'Invalid render options. Provide either html or json.'
      [ 500, { 'Content-Type' => 'application/json' }, [ JSON.generate({ error: 'Invalid render options. Provide either html or json.' }) ] ]
    end
  end
end
