# frozen_string_literal: true

module Middlewares
  class DefaultResponse
    def initialize(app)
      @app = app
    end

    def call(env)
      status, headers, body = @app.call(env)

      if headers['Content-Type'].nil? && (body[0].is_a?(Hash) || body[0].is_a?(Array) || (body[0].is_a?(String) && body[0].valid_json?))
        headers['Content-Type'] = 'application/json'
      end

      if headers['Content-Type'] == 'application/json' && (body[0].is_a?(Hash) || body[0].is_a?(Array))
        body = [JSON.generate(body[0])]
      end

      [status, headers, body]
    rescue StandardError => e
      puts e.message
      puts e.backtrace
      [500, { 'Content-Type' => 'application/json' }, [JSON.generate({ error: e.message })]]
    end
  end
end